@@ -43,12 +43,12 @@
 
 /* Define the version number so folks can check against it */
 #define TC_VERSION_MAJOR  2
-#define TC_VERSION_MINOR  9
-#define TC_VERSION_PATCH  ".1"
-#define TC_VERSION_STRING "gperftools 2.9.1"
+#define TC_VERSION_MINOR  15
+#define TC_VERSION_PATCH  ""
+#define TC_VERSION_STRING "gperftools 2.15"
 
 /* For struct mallinfo, if it's defined. */
-#if 1
+#if 1 || 1 
 # include <malloc.h>
 #endif
 
@@ -107,6 +107,9 @@ extern "C" {
 #if 1
   PERFTOOLS_DLL_DECL struct mallinfo tc_mallinfo(void) PERFTOOLS_NOTHROW;
 #endif
+#if 1
+  PERFTOOLS_DLL_DECL struct mallinfo2 tc_mallinfo2(void) PERFTOOLS_NOTHROW;
+#endif
 
   /*
    * This is an alias for MallocExtension::instance()->GetAllocatedSize().
